@@ -96,8 +96,9 @@ namespace Tomboy
 					if (tabAddin.GetPreferenceTabWidget (this, out tabName, out tabWidget) == true) {
 						notebook.AppendPage (tabWidget, new Gtk.Label (tabName));
 					}
-				} catch {
+				} catch (Exception e) {
 					Logger.Warn ("Problems adding preferences tab addin: {0}", tabAddin.GetType ().Name);
+					Logger.Debug ("{0}:\n{1}", e.Message, e.StackTrace);
 				}
 			}
 
@@ -530,7 +531,6 @@ namespace Tomboy
 			autosyncBox.PackStart (autosyncCheck);
 			autosyncBox.PackStart (autosyncSpinner);
 			autosyncBox.PackStart (autosyncExtraText);
-			autosyncBox.Sensitive = false; // TODO: Remove when this feature is stable
 			vbox.PackStart (autosyncBox, false, true, 0);
 
 			Gtk.HButtonBox bbox = new Gtk.HButtonBox ();
@@ -1147,7 +1147,7 @@ namespace Tomboy
 				                              Gtk.DialogFlags.Modal,
 				                              Gtk.MessageType.Question,
 				                              Gtk.ButtonsType.YesNo,
-				                              Catalog.GetString ("WARNING: Are you sure?"),
+				                              Catalog.GetString ("Are you sure?"),
 				                              Catalog.GetString (
 				                                      "Clearing your synchronization settings is not recommended.  " +
 				                                      "You may be forced to synchronize all of your notes again " +
@@ -1242,7 +1242,7 @@ namespace Tomboy
 				                              Gtk.DialogFlags.Modal,
 				                              Gtk.MessageType.Info,
 				                              Gtk.ButtonsType.YesNo,
-				                              Catalog.GetString ("Success! You're connected!"),
+				                              Catalog.GetString ("Connection successful"),
 				                              Catalog.GetString (
 				                                      "Tomboy is ready to synchronize your notes. Would you like to synchronize them now?"));
 				int response = dialog.Run ();
@@ -1267,10 +1267,9 @@ namespace Tomboy
 				// Give the user a visual letting them know that connecting
 				// was successful.
 				if (errorMsg == null) {
-					errorMsg = Catalog.GetString ("Sorry, but something went wrong.  " +
-					                              "Please check your information and " +
-					                              "try again.  The {0} might " +
-					                              "be useful too.");
+					errorMsg = Catalog.GetString ("Please check your information and " +
+					                              "try again.  The log file {0} may " +
+					                              "contain more information about the error.");
 					string logPath = System.IO.Path.Combine (Services.NativeApplication.LogDirectory,
 					                                         "tomboy.log");
 					errorMsg = String.Format (errorMsg, logPath);
@@ -1280,7 +1279,7 @@ namespace Tomboy
 				                              Gtk.DialogFlags.Modal,
 				                              Gtk.MessageType.Warning,
 				                              Gtk.ButtonsType.Close,
-				                              Catalog.GetString ("Error connecting :("),
+				                              Catalog.GetString ("Error connecting"),
 				                              errorMsg);
 				dialog.Run ();
 				dialog.Destroy ();
